@@ -5,21 +5,25 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#include <QApplication>
 #include <QMetaObject>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QQmlEngine>
+#include <QQuickStyle>
 #include <QUrl>
 #include <QtQml>
 
+#ifdef Q_OS_ANDROID
+#include <QGuiApplication>
+#else
+#include <QApplication>
+#endif
+
 #include <KAboutData>
 #include <KConfigCore/KConfig>
 #include <KLocalizedContext>
 #include <KLocalizedString>
 
-#include "abstractdailyweatherforecast.h"
-#include "abstracthourlyweatherforecast.h"
 #include "kweathersettings.h"
 #include "locationquerymodel.h"
 #include "weatherdaymodel.h"
@@ -27,6 +31,7 @@
 #include "weatherhourmodel.h"
 #include "weatherlocation.h"
 #include "weatherlocationmodel.h"
+#include "version.h"
 
 class AbstractHourlyWeatherForecast;
 class AbstractDailyWeatherForecast;
@@ -34,26 +39,35 @@ class AbstractDailyWeatherForecast;
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+
+#ifdef Q_OS_ANDROID
+    QGuiApplication app(argc, argv);
+    QQuickStyle::setStyle(QStringLiteral("Material"));
+#else
     QApplication app(argc, argv);
+    if(qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+    }
+#endif
     QQmlApplicationEngine engine;
 
     KLocalizedString::setApplicationDomain("kweather");
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    KAboutData aboutData("kweather", i18n("Weather"), "0.3", i18n("Weather application in Kirigami"), KAboutLicense::GPL, i18n("© 2020 KDE Community"));
+    KAboutData aboutData("kweather", i18n("Weather"), QStringLiteral(KWEATHER_VERSION_STRING), i18n("A convergent weather application for Plasma"), KAboutLicense::GPL, i18n("© 2020-2021 Plasma Development Team"));
+    aboutData.addAuthor(i18n("Han Young"), QString(), QStringLiteral("hanyoung@protonmail.com"));
+    aboutData.addAuthor(i18n("Devin Lin"), QString(), QStringLiteral("espidev@gmail.com"), QStringLiteral("https://espi.dev"));
     KAboutData::setApplicationData(aboutData);
 
-    // initialize models in context
-    auto *weatherLocationListModel = new WeatherLocationListModel();
-    auto *locationQueryModel = new LocationQueryModel();
-    WeatherForecastManager::instance(*weatherLocationListModel);
+    engine.rootContext()->setContextProperty(QStringLiteral("kweatherAboutData"), QVariant::fromValue(aboutData));
 
+    // initialize models in context
+    auto *locationQueryModel = new LocationQueryModel();
+    QObject::connect(locationQueryModel, &LocationQueryModel::appendLocation, WeatherForecastManager::inst()->model(), &WeatherLocationListModel::addLocation);
     KWeatherSettings settings;
 
-    engine.rootContext()->setContextProperty("weatherLocationListModel", weatherLocationListModel);
-    engine.rootContext()->setContextProperty("locationQueryModel", locationQueryModel);
+    engine.rootContext()->setContextProperty("weatherLocationListModel", WeatherForecastManager::inst()->model());
     engine.rootContext()->setContextProperty("settingsModel", &settings);
-    // the longer the merrier, this add locations
-    QObject::connect(locationQueryModel, &LocationQueryModel::appendLocation, [weatherLocationListModel, locationQueryModel] { weatherLocationListModel->addLocation(locationQueryModel->get(locationQueryModel->index_)); });
+    engine.rootContext()->setContextProperty("locationQueryModel", locationQueryModel);
 
     // register QML types
     qmlRegisterType<WeatherLocation>("kweather", 1, 0, "WeatherLocation");
