@@ -133,6 +133,11 @@ public:
 
     const QVariantList &maxTempList();
     const QVariantList &xAxisList();
+
+    // for restore order of locations
+    void saveOrder(int index);
+    int index();
+    void deleteConfig();
 public slots:
     void updateData(QExplicitlySharedDataPointer<KWeatherCore::WeatherForecast> forecasts);
 
