@@ -31,12 +31,34 @@ void WeatherLocationListModel::load()
         if (location_ptr)
             m_locations.push_back(location_ptr);
     }
+
+    auto i {0};
+    for (auto loc : m_locations) {
+        auto index = loc->index();
+        while (index != i) {
+            if (index != -1) {
+                if (index >= (int)m_locations.size()) {
+                    qDebug() << "invalid index, please delete config(~/.config/kweather/kweatherrc)";
+                    abort();
+                } else {
+                    std::swap(m_locations[i], m_locations[index]);
+                    index = m_locations[i]->index();
+                }
+            } else {
+                loc->saveOrder(i);
+                index = i;
+            }
+        }
+        i++;
+    }
 }
 
-void WeatherLocationListModel::save()
+void WeatherLocationListModel::saveOrder()
 {
-    for (auto location : m_locations) {
-        location->save();
+    auto i {0};
+    for (auto loc : m_locations) {
+        loc->saveOrder(i);
+        i++;
     }
 }
 
@@ -82,7 +104,8 @@ void WeatherLocationListModel::insert(int index, WeatherLocation *weatherLocatio
     m_locations.insert(m_locations.begin() + index, weatherLocation);
     endInsertRows();
 
-    save();
+    saveOrder();
+    weatherLocation->save();
 }
 
 void WeatherLocationListModel::remove(int index)
@@ -93,10 +116,10 @@ void WeatherLocationListModel::remove(int index)
     beginRemoveRows(QModelIndex(), index, index);
     auto location = m_locations.at(index);
     m_locations.erase(m_locations.begin() + index);
-    delete location;
+    location->deleteConfig();
+    location->deleteLater();
     endRemoveRows();
-
-    save();
+    saveOrder();
 }
 
 WeatherLocation *WeatherLocationListModel::get(int index)
@@ -119,6 +142,8 @@ void WeatherLocationListModel::move(int oldIndex, int newIndex)
     beginMoveRows(QModelIndex(), oldIndex, oldIndex, QModelIndex(), newIndex);
     std::iter_swap(m_locations.begin() + oldIndex, m_locations.begin() + newIndex);
     endMoveRows();
+
+    saveOrder();
 }
 int WeatherLocationListModel::count() const
 {
